@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Union
 
 from fastapi import Body, FastAPI
 from pydantic import BaseModel
@@ -8,9 +8,9 @@ app = FastAPI()
 
 class Item(BaseModel):
     name: str
-    description: Optional[str] = None
+    description: Union[str, None] = None
     price: float
-    tax: Optional[float] = None
+    tax: Union[float, None] = None
 
 
 @app.put("/items/{item_id}")
@@ -18,9 +18,8 @@ async def update_item(
     *,
     item_id: int,
     item: Item = Body(
-        ...,
-        examples={
-            "normal": {
+        examples=[
+            {
                 "summary": "A normal example",
                 "description": "A **normal** item works correctly.",
                 "value": {
@@ -30,7 +29,7 @@ async def update_item(
                     "tax": 3.2,
                 },
             },
-            "converted": {
+            {
                 "summary": "An example with converted data",
                 "description": "FastAPI can convert price `strings` to actual `numbers` automatically",
                 "value": {
@@ -38,14 +37,14 @@ async def update_item(
                     "price": "35.4",
                 },
             },
-            "invalid": {
+            {
                 "summary": "Invalid data is rejected with an error",
                 "value": {
                     "name": "Baz",
                     "price": "thirty five point four",
                 },
             },
-        },
+        ],
     ),
 ):
     results = {"item_id": item_id, "item": item}
