@@ -16,8 +16,8 @@ async def update_item(
     *,
     item_id: int,
     item: Item = Body(
-        examples={
-            "normal": {
+        examples=[
+            {
                 "summary": "A normal example",
                 "description": "A **normal** item works correctly.",
                 "value": {
@@ -27,7 +27,7 @@ async def update_item(
                     "tax": 3.2,
                 },
             },
-            "converted": {
+            {
                 "summary": "An example with converted data",
                 "description": "FastAPI can convert price `strings` to actual `numbers` automatically",
                 "value": {
@@ -35,14 +35,14 @@ async def update_item(
                     "price": "35.4",
                 },
             },
-            "invalid": {
+            {
                 "summary": "Invalid data is rejected with an error",
                 "value": {
                     "name": "Baz",
                     "price": "thirty five point four",
                 },
             },
-        },
+        ],
     ),
 ):
     results = {"item_id": item_id, "item": item}
