@@ -1,3 +1,5 @@
+from collections import deque
+from dataclasses import dataclass
 from datetime import datetime, timezone
 from enum import Enum
 from pathlib import PurePath, PurePosixPath, PureWindowsPath
@@ -19,6 +21,12 @@ class Pet:
         self.name = name
 
 
+@dataclass
+class Item:
+    name: str
+    count: int
+
+
 class DictablePerson(Person):
     def __iter__(self):
         return ((k, v) for k, v in self.__dict__.items())
@@ -131,6 +139,15 @@ def test_encode_dictable():
     }
 
 
+def test_encode_dataclass():
+    item = Item(name="foo", count=100)
+    assert jsonable_encoder(item) == {"name": "foo", "count": 100}
+    assert jsonable_encoder(item, include={"name"}) == {"name": "foo"}
+    assert jsonable_encoder(item, exclude={"count"}) == {"name": "foo"}
+    assert jsonable_encoder(item, include={}) == {}
+    assert jsonable_encoder(item, exclude={}) == {"name": "foo", "count": 100}
+
+
 def test_encode_unsupported():
     unserializable = Unserializable()
     with pytest.raises(ValueError):
@@ -221,3 +238,12 @@ def test_encode_model_with_path(model_with_path):
 def test_encode_root():
     model = ModelWithRoot(__root__="Foo")
     assert jsonable_encoder(model) == "Foo"
+
+
+def test_encode_deque_encodes_child_models():
+    class Model(BaseModel):
+        test: str
+
+    dq = deque([Model(test="test")])
+
+    assert jsonable_encoder(dq)[0]["test"] == "test"
